ext/rest.py
branchstable
changeset 6275 20f30e01ae59
parent 6109 47d9c0e0f7b7
child 6938 6c1a960735f5
--- a/ext/rest.py	Thu Sep 16 18:41:45 2010 +0200
+++ b/ext/rest.py	Thu Sep 16 18:43:03 2010 +0200
@@ -242,8 +242,14 @@
         data = data.translate(ESC_CAR_TABLE)
     settings = {'input_encoding': encoding, 'output_encoding': 'unicode',
                 'warning_stream': StringIO(),
+                'traceback': True, # don't sys.exit
+                'stylesheet': None, # don't try to embed stylesheet (may cause
+                                    # obscure bug due to docutils computing
+                                    # relative path according to the directory
+                                    # used *at import time*
                 # dunno what's the max, severe is 4, and we never want a crash
                 # (though try/except may be a better option...)
                 'halt_level': 10,
                 }
     if context:
@@ -242,8 +242,14 @@
                 # dunno what's the max, severe is 4, and we never want a crash
-                # (though try/except may be a better option...)
+                # (though try/except may be a better option...). May be the
+                # above traceback option will avoid this?
                 'halt_level': 10,
                 }